pub struct Session { /* private fields */ }Expand description
A collection of Pages, uniquely keyed by a String path, which are
periodically pruned by a garbage collector thread to remove inactive and
empty pages from the pool.
Implementations